@@ -1,22 +1,7 @@
-try:    
-    from .getkey import getkey
-except ImportError:
-    from getkey import  getkey
-try:
-    from .decorators import with_args
-except ImportError:
-    from decorators import with_args
-try:
-    from . import term
-except ImportError:
-    try:
-        import term
-    except ImportError:
-        term=None
-try:
-    from .ctrl import CTRLIN
-except ImportError:
-    from ctrl import CTRLIN
+from .getkey import getkey
+from .decorators import with_args
+from . import term
+from .ctrl import CTRLIN
 import os
 class HotKeyListener:
     def __init__(self,catch=False,blocking=True):
