@@ -4,14 +4,8 @@ import termios
 import os
 import time
 import fcntl
-try:
-    from . import term
-except ImportError:
-    import term
-try:
-    from .ctrl import *
-except ImportError:
-    from ctrl import *
+from . import term
+from .ctrl import *
 import sys
 class NoBufReader:
     def __init__(self,file):
