@@ -1,6 +1,6 @@
 import msvcrt
 from .ctrl import *
-def getkey(blocking=True,tout=0.1,catch=False):
+def getkey(blocking=True,tout=0.1,catch=False,echo=False):
     if not blocking:
         if msvcrt.kbhit():
             key=msvcrt.getch()
@@ -11,4 +11,6 @@ def getkey(blocking=True,tout=0.1,catch=False):
             if not catch:
                 raise
             key='\x03'
+    if key.isprintable() and echo:
+        print(key,end='',flush=True)
     return parse_key(key)
